Ext.define('AS.ARC.apps.syslogServer.notification.main', {
    extend: 'AS.ARC.apps.syslogServer.page',
	pageTag: 'main',
    imgUrl: AS.ARC.util.getUserAppsPath() + 'syslogServer/images/',
    
	handleApply: function() {
		var page = this,
			urlOpts = {
				act: 'Notifacation',
            	tab: 'Set_Setting'
			},
			params = page.fp.doDataExchange();
		
		if (!page.fp.isSettingChange(params)) {
			page.fp.showSetNotChange();
			return false;
		} // end if

		page.fn.app.maskWin(_S('COMMON', 'APPLYING'));
		
        AS.ARC.ajax({
            url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', urlOpts),
            method: 'post',
            params: params,
            success: function(json, opts) {
                page.fp.uiChecker.srcData = params;
                page.fp.showApply();
                page.fn.app.unmaskWin();
            },
            failure: function(json, opts) {
                var errors = {
                    5000: _S('ERROR', 'SESSION_TIMEOUT'),
					5401: _S('ERROR', 'UNABLE_APPLY_SETTINGS')
                };
                
                page.fn.app.unmaskWin();
                AS.ARC.util.showMsgWindow(errors, json, page.fn.app.win, 'warning', function() {page.loadData();});
            }
        });
	},

	getPanel: function() {
		var page = this;

        page.buttonApply = Ext.create('Ext.button.Button', {
			xtype: 'button',
			text: _S('COMMON', 'APPLY')
		});
        
		return {
			xtype: 'asFnForm',
			page: page,
			itemId: page.panelItemId,
            title: _S('SYSLOG_SERVER', 'NOTIFICATION'),
			border: false,
			cls: 'as-page-panel',
            buttonAlign: 'left',
			fbar: [
				{
					xtype: 'tbfill'
				},
				page.buttonApply
			],
			items: [
				{
					xtype: 'fieldset',
					itemId: 'notificationSettingsFieldset',
					title: _S('SYSLOG_SERVER', 'SET_NOTIFICATION'),
					width: 678,
					items: [
						{
							xtype: 'container',
							itemId: 'countLimitContainer',
							width: 660,
							layout: 'hbox',
							defaults: {
								margin: '0 3 0 0'
							},
							items: [
								{
									xtype: 'checkbox',
									itemId: 'countLimitCheckbox',
									width: 300,
									boxLabel: _S('SYSLOG_SERVER', 'COUNT_ONE_MINUTE'),
									handler: function(checkbox, checked) {
										if (checked) {
											page.countLimitValue.enable();
										} else {
											page.countLimitValue.disable();
										}
									}
								},
								{
									xtype: 'numberfield',
									itemId: 'countLimitValue',
									msgTarget: AS.ARC.config.msgTarget,
									minValue: 1,
									maxValue: 999999999,
									value: 1,
									allowBlank: false
								}
							]
						},
						{
							xtype: 'container',
							itemId: 'serverityContainer',
							width: 660,
							layout: 'hbox',
							defaults: {
								margin: '0 3 0 0'
							},
							items: [
								{
									xtype: 'checkbox',
									itemId: 'severityCheckbox',
									boxLabel: _S('SYSLOG_SERVER', 'SEVERITY'),
									width: 300,
									handler: function(checkbox, checked) {
										if (checked) {
											page.severityValue.enable();
										} else {
											page.severityValue.disable();
										}
									}
								},
								{
									xtype: 'combobox',
									itemId: 'severityValue',
									width: 220,
									store: {
										fields: ['value', 'text'],
										data: [
											{'value': 0, 'text': _UN_TS('Emergency')},
											{'value': 1, 'text': Ext.String.format('{0}, {1}', _UN_TS('Alert'), _UN_TS('Emergency'))},
											{'value': 2, 'text': Ext.String.format('{0}, {1}, {2}', _UN_TS('Critical'), _UN_TS('Alert'), _UN_TS('Emergency'))},
											{'value': 3, 'text': Ext.String.format('{0}, {1}, {2}, {3}', _UN_TS('Error'), _UN_TS('Critical'), _UN_TS('Alert'), _UN_TS('Emergency'))}
										]
									},
									editable: false,
									value: 0,
									triggerAction: 'all',
									valueField: 'value',
									displayField: 'text'
								}
							]
						},
						{
							xtype: 'container',
							itemId: 'keywordContainer',
							width: 660,
							layout: 'hbox',
							defaults: {
								margin: '0 3 0 0'
							},
							items: [
								{
									xtype: 'checkbox',
									itemId: 'keywordCheckbox',
									boxLabel: _S('SYSLOG_SERVER', 'KEYWORD'),
									width: 300,
									handler: function(checkbox, checked) {
										if (checked) {
											page.firstKeywordValue.enable();
											page.secondKeywordValue.enable();
											page.thirdKeywordValue.enable();
										} else {
											page.firstKeywordValue.disable();
											page.secondKeywordValue.disable();
											page.thirdKeywordValue.disable();
										}
									}
								},
								{
									xtype: 'container',
									cls: 'common-layout-vertical-3-0',
									items: [
										{
											xtype: 'textfield',
											itemId: 'firstKeywordValue',
											width: 100
										},
										{
											xtype: 'textfield',
											itemId: 'secondKeywordValue',
											width: 100
										},
										{
											xtype: 'textfield',
											itemId: 'thirdKeywordValue',
											width: 100
										}
									]
								}
							]
						}
					]
				}
			],
            doDataExchange: function() {
				var isEnableCountLimit,
					countLimit = page.countLimitValue.getValue(),
					isEnableSeverity,
					severity = page.severityValue.getValue(),
					isEnableKeyword,
                    keywordCount = 0,
                    firstKeyword = page.firstKeywordValue.getValue(),
                    secondKeyword = page.secondKeywordValue.getValue(),
                    thirdKeyword = page.thirdKeywordValue.getValue();
				
				isEnableCountLimit = page.countLimitCheckbox.checked ? 1 : 0;
				
				isEnableSeverity = page.severityCheckbox.checked ? 1 : 0;
				
				isEnableKeyword = page.keywordCheckbox.checked ? 1 : 0;

                if (firstKeyword !== '') {
                    keywordCount++;
                }

                if (secondKeyword !== '') {
                    keywordCount++;
                }

                if (thirdKeyword !== '') {
                    keywordCount++;
                }
                
                var pageData = {
                    enable_number: isEnableCountLimit, 
                    number: countLimit, 
                    enable_level: isEnableSeverity, 
                    level: severity, 
                    enable_keyword: isEnableKeyword, 
                    keyword_count: keywordCount, 
                    keyword1: firstKeyword, 
                    keyword2: secondKeyword, 
                    keyword3: thirdKeyword
                };
                
				return pageData;
			}
		};
	},
	
	loadData: function() {
		var page = this;

		page.fn.app.maskWin(_S('COMMON', 'LOADING'));

		page.countLimitCheckbox = page.fn.tabPanel.down('#countLimitCheckbox');
		page.countLimitValue = page.fn.tabPanel.down('#countLimitValue');
		page.severityCheckbox = page.fn.tabPanel.down('#severityCheckbox');
		page.severityValue = page.fn.tabPanel.down('#severityValue');
		page.keywordCheckbox = page.fn.tabPanel.down('#keywordCheckbox');
		page.firstKeywordValue = page.fn.tabPanel.down('#firstKeywordValue');
		page.secondKeywordValue = page.fn.tabPanel.down('#secondKeywordValue');
		page.thirdKeywordValue = page.fn.tabPanel.down('#thirdKeywordValue');

		AS.ARC.ajax({
			url: AS.ARC.util.getApiUrlWithSid(AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi', {act: 'Notifacation', tab: 'Get_Setting'}),
			method: 'post',
			success: function(json, opts) {
				page.fp.uiChecker.srcData = json;

				if (json.mail === 'provider') {
					var notSettingEmailMsg = _S('SYSLOG_SERVER', 'NO_MAIL_PROVIDER') + ' ' + 
											Ext.String.format(
												_S('SYSLOG_SERVER', 'CLICK_HERE_TO_CONFIGURE'), 
												'<a href="#" onclick="AS.ARC.core.openApp(\'app-settings\', \'notification\', 0);">', 
												'</a>'
											);

					page.fn.tabPanel.down('#panel-main').el.mask(notSettingEmailMsg, 'as-mask-msg');
				} else if (json.mail === 'receiver') {
					var notSettingEmailMsg = _S('SYSLOG_SERVER', 'NO_MAIL_RECEIVER') + ' ' + 
											Ext.String.format(
												_S('SYSLOG_SERVER', 'CLICK_HERE_TO_CONFIGURE'), 
												'<a href="#" onclick="AS.ARC.core.openApp(\'app-settings\', \'notification\', 1);">', 
												'</a>'
											);

					page.fn.tabPanel.down('#panel-main').el.mask(notSettingEmailMsg, 'as-mask-msg');
				} else {
					if (json.enable_number === 0) {
                        page.countLimitCheckbox.setValue(false);
                        page.countLimitValue.disable();
                    } else {
                        page.countLimitCheckbox.setValue(true);
                        page.countLimitValue.enable();
					}
					
					if (json.enable_level === 0) {
                        page.severityCheckbox.setValue(false);
                        page.severityValue.disable();
                    } else {
                        page.severityCheckbox.setValue(true);
                        page.severityValue.enable();
					}
					
					if (json.enable_keyword === 0) {
                        page.keywordCheckbox.setValue(false);
                        page.firstKeywordValue.disable();
                        page.secondKeywordValue.disable();
                        page.thirdKeywordValue.disable();
                    } else {
                        page.keywordCheckbox.setValue(true);
                        page.firstKeywordValue.enable();
                        page.secondKeywordValue.enable();
                        page.thirdKeywordValue.enable();
					}
					
					page.countLimitValue.setValue(json.number);
                    page.severityValue.setValue(json.level);
                    page.firstKeywordValue.setValue(json.keyword1);
                    page.secondKeywordValue.setValue(json.keyword2);
                    page.thirdKeywordValue.setValue(json.keyword3);

					page.fn.tabPanel.down('#panel-main').el.unmask();
				}

				page.fn.app.unmaskWin();
			},
			failure: function(json, opts) {
				page.fn.app.unmaskWin();
				AS.ARC.util.showMsgWindow({
					5000: _S('ERROR', 'SESSION_TIMEOUT'),
					5401: _S('ERROR', 'UNABLE_APPLY_SETTINGS')
				}, json, page.fn.app.win);
			}
		});
	}
});

/**
 * @class AS.ARC.apps.syslogServer.notification.fn
 * @extends AS.ARC.apps.syslogServer.fn
 * <p></p>
 */
Ext.define('AS.ARC.apps.syslogServer.notification.fn', {
	extend: 'AS.ARC.apps.syslogServer.fn',

	fnTag: 'notification',
	
	init: function (config) {
		this.apiUrl = AS.ARC.util.getUserAppsPath() + 'syslogServer/syslog-server.cgi',
		this.createPanel();
	},
    
	createPanel: function () {
		var fn = this;
		
		var pageNotification = new AS.ARC.apps.syslogServer.notification.main({fn: this});
			
		this.tabPanel = Ext.create('AS.ARC.fnTabPanel', {
			items: [
				pageNotification.getPanel()
			]
		});
        
		fn.initMainPanel();
	},
	
	loadData: function () {
		this.tabPanel.activeTab.page.loadData(true);
	}
});